sequencetools.iterate_sequence_forward_and_backward_overlapping
===============================================================

.. autofunction:: abjad.tools.sequencetools.iterate_sequence_forward_and_backward_overlapping.iterate_sequence_forward_and_backward_overlapping
